@@ -103,11 +103,11 @@ QString ColorSchemeManager::colorSchemeNameFromPath(const QString &path)
 
 QStringList ColorSchemeManager::listColorSchemes()
 {
-    QStringList colorschemes;
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole"), QStandardPaths::LocateDirectory);
-    colorschemes.reserve(dirs.size());
+    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole"), QStandardPaths::LocateDirectory);
+    dirs.append(QStringLiteral(":/konsole/color-schemes")); // fallback to bundled ones
 
-    for (const QString &dir : dirs) {
+    QStringList colorschemes;
+    for (const QString &dir : std::as_const(dirs)) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.colorscheme"));
         for (const QString &file : fileNames) {
             colorschemes.append(dir + QLatin1Char('/') + file);
@@ -185,12 +185,16 @@ std::shared_ptr<const ColorScheme> ColorSchemeManager::findColorScheme(const QSt
 QString ColorSchemeManager::findColorSchemePath(const QString &name) const
 {
     QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".colorscheme"));
-
-    if (!path.isEmpty()) {
-        return path;
+    if (path.isEmpty()) {
+        path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".schema"));
     }
-
-    return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + name + QStringLiteral(".schema"));
+    if (path.isEmpty()) {
+        const QString resource = QStringLiteral(":/konsole/color-schemes/") + name + QStringLiteral(".colorscheme");
+        if (QFile::exists(resource)) {
+            path = resource;
+        }
+    }
+    return path;
 }
 
 bool ColorSchemeManager::pathIsColorScheme(const QString &path)
